#!/usr/bin/env python3


def test_is_mandatory():
    assert "3" in "km3irf"
